/**
 * <p>Класс Employee реализует интерфейс Comparable<Employee></p>
 * */
public class Employee implements Comparable<Employee> {
    private String name;
    private double salary;

    /**
     * <p>Конструктор класса Employee</p>
     * @param name Имя сотрудника
     * @param salary Зарплата сотрудника
     * */
    public Employee(String name, double salary) {
        this.name = name;
        this.salary = salary;
    }

    /**
     * <p>Функция для получения имени сотрудника</p>
     * @return Имя сотрудника
     * */
    public String getName() {
        return name;
    }

    /**
     * <p>Функция для получения зарплаты сотрудника</p>
     * @return Зарплата сотрудника
     * */
    public double getSalary() {
        return salary;
    }

    /**
     * <p>Функция для увеличения заработной платы сотрудника на заданое количество процентов</p>
     * @param byPercent Количество процентов
     * */
    public void raiseSalary(double byPercent) {
        double raise = salary * byPercent / 100;
        salary += raise;
    }

    /**
     * <p>Функция из интерфейса Comparable.</p>
     * <p>Сравнивает два объекта класса Employee.</p>
     * @return -1, если o.salary > salary. 0, если o.salary = salary. 1, если o.salary < salary
     * */
    @Override
    public int compareTo(Employee o) {
        return Double.compare(salary, o.salary);
    }
}
